lilypondnametools.LilyPondContextSetting
========================================

.. abjad-lineage:: abjad.tools.lilypondnametools.LilyPondContextSetting.LilyPondContextSetting

.. autoclass:: abjad.tools.lilypondnametools.LilyPondContextSetting.LilyPondContextSetting

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondnametools.LilyPondContextSetting.LilyPondContextSetting.context_name
      ~abjad.tools.lilypondnametools.LilyPondContextSetting.LilyPondContextSetting.context_property
      ~abjad.tools.lilypondnametools.LilyPondContextSetting.LilyPondContextSetting.format_pieces
      ~abjad.tools.lilypondnametools.LilyPondContextSetting.LilyPondContextSetting.is_unset
      ~abjad.tools.lilypondnametools.LilyPondContextSetting.LilyPondContextSetting.value
      ~abjad.tools.lilypondnametools.LilyPondContextSetting.LilyPondContextSetting.__eq__
      ~abjad.tools.lilypondnametools.LilyPondContextSetting.LilyPondContextSetting.__format__
      ~abjad.tools.lilypondnametools.LilyPondContextSetting.LilyPondContextSetting.__hash__
      ~abjad.tools.lilypondnametools.LilyPondContextSetting.LilyPondContextSetting.__ne__
      ~abjad.tools.lilypondnametools.LilyPondContextSetting.LilyPondContextSetting.__repr__

Bases
-----

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.lilypondnametools.LilyPondContextSetting.LilyPondContextSetting.context_name
   :noindex:

.. autoattribute:: abjad.tools.lilypondnametools.LilyPondContextSetting.LilyPondContextSetting.context_property
   :noindex:

.. autoattribute:: abjad.tools.lilypondnametools.LilyPondContextSetting.LilyPondContextSetting.format_pieces
   :noindex:

.. autoattribute:: abjad.tools.lilypondnametools.LilyPondContextSetting.LilyPondContextSetting.is_unset
   :noindex:

.. autoattribute:: abjad.tools.lilypondnametools.LilyPondContextSetting.LilyPondContextSetting.value
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.lilypondnametools.LilyPondContextSetting.LilyPondContextSetting.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondnametools.LilyPondContextSetting.LilyPondContextSetting.__format__
   :noindex:

.. automethod:: abjad.tools.lilypondnametools.LilyPondContextSetting.LilyPondContextSetting.__hash__
   :noindex:

.. automethod:: abjad.tools.lilypondnametools.LilyPondContextSetting.LilyPondContextSetting.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondnametools.LilyPondContextSetting.LilyPondContextSetting.__repr__
   :noindex:
